@@ -16,30 +16,10 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: calendar.pl,v 1.36 2005/01/06 12:05:15 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: calendar.pl,v 1.37 2005/10/07 23:23:30 as Exp $</p>';
 
 use vars qw($CalendarOnEveryPage $CalendarUseCal);
 
-$DefaultStyleSheet .= q{
-div.month { margin:0; padding:0; font-size:x-small; float:right; }
-div.content div.month { float:none; }
-div.footer { clear:both; }
-div.year div.month { float:left; font-size:medium; padding:1ex; }
-div.month pre { margin:0; padding:0 0 0 1ex; background-color:#ffe; width:21ex; }
-div.month a { text-decoration:none; color:inherit; }
-div.month span.title a { background-color:inherit; }
-div.month a.exact { background-color:#eef; }
-div.month a.collection { background-color:#ccf; }
-div.month a.today { background-color:#fcc; }
-div.month a[class~="today"][class~="exact"] { background-color:#fcf; }
-div.month a[class~="today"][class~="collection"] { background-color:#faf; }
-@media print {
-  div.month { display: none; }
-  div.year div.month { display: block; }
-  div.year div.month a { display: inline; }
-}
-} unless $DefaultStyleSheet =~ /div\.month/; # mod_perl?
-
 $CalendarOnEveryPage = 1;
 $CalendarUseCal = 1;
 
