@@ -24,8 +24,8 @@
 #
 # This translation was last checked for Oddmuse version 1.215.
 #
-$ModulesDescription .= '<p>$Id: dutch-utf8.pl,v 1.3 2005/07/02 00:03:28 as Exp $</p>';
-%Translate = split('\n',<<END_OF_TRANSLATION);
+$ModulesDescription .= '<p>$Id: dutch-utf8.pl,v 1.6 2005/10/09 12:48:35 as Exp $</p>';
+%Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 U mag deze pagina niet lezen: uw account op deze Wiki, uw IP of uw netwerk is buitengesloten.
 Could not create %s
@@ -112,6 +112,10 @@ List later changes
 Toon latere veranderingen
 Filters
 Filters
+Title:
+
+Title and Body:
+
 Username:
 Gebruikersnaam:
 Host:
@@ -128,6 +132,8 @@ new
 nieuw
 from %s
 vanaf %s
+This page is too big to send over RSS.
+
 History of %s
 Geschiedenis van %s
 Compare
@@ -152,8 +158,6 @@ Wiki Version
 Tonen van Wiki-versie
 Unlock Wiki
 Bezig met ontgrendelen
-Recent Visitors
-Recente bezoekers
 Password
 Wachtwoord
 Run maintenance
@@ -162,6 +166,8 @@ Unlock site
 Ontgrendel site
 Lock site
 Vergrendel site
+Install CSS
+
 Unlock %s
 
 Lock %s
@@ -246,6 +252,8 @@ minor
 klein
 No diff available.
 Er is geen verschillenanalyse beschikbaar.
+The two revisions are the same.
+
 Old revision:
 
 Changed:
@@ -294,7 +302,7 @@ Ontgrendelen is niet nodig.
 1 seconde geleden
 just now
 precies op dit moment
-Editing Denied
+Edit Denied
 Wijzigen niet toegestaan
 Editing not allowed: user, ip, or network is blocked.
 U mag deze pagina niet wijzigen: uw account op deze Wiki, uw IP of uw netwerk is buitengesloten.
@@ -362,6 +370,8 @@ Include near pages
 
 (for %s)
 (voor %s)
+Filter:
+
 %s pages found.
 %s pagina's gevonden
 Replaced: %s
@@ -406,10 +416,10 @@ Browser reports no file info.
 Uw browser heeft geen informatie over het bestand opgegeven.
 Browser reports no file type.
 Uw browser heeft geen informatie over het bestandstype opgegeven.
-Edit Denied
-Wijzigen niet toegestaan
 The page contains banned text.
 Deze pagina bevat verbannen tekst.
+No changes to be saved.
+
 This page was changed by somebody else %s.
 Deze pagina is gewijzigd door iemand anders %s.
 The changes conflict.  Please check the page again.
@@ -492,6 +502,8 @@ Click to search for references to this permanent anchor
 Klik hier om te zoeken naar verwijzingen naar deze permanente bladwijzer
 the page %s also exists
 de pagina %s bestaat ook
+Copy one of the following stylesheets to %s:
+
 Deleting %s
 Bezig met verwijderen van %s
 Deleted %s
@@ -516,6 +528,14 @@ Rename %s to:
 
 Cannot highlight the language %s.
 
+Recent Visitors
+Recente bezoekers
+some action
+
+was here
+
+and read
+
 Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
 Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
 The match parameter is missing.
@@ -550,10 +570,18 @@ Marked as %s.
 
 Cannot find unspammed revision.
 
+Add Comment
+
+ordinary changes
+
 Footnotes:
 Voetnoten:
 Could not find %1.html template in %2
 
+Only Editors are allowed to see hidden pages.
+
+Only Admins are allowed to see hidden pages.
+
 image: %s
 afbeelding: %s
 Index
@@ -586,6 +614,10 @@ Your registration for %s has been submitted.
 
   Please allow time for the webmaster to approve your request.
 
+  An email has been sent to "%s" with further instructions.
+
+There was an error saving your registration.
+
 An account was created for %s.
 
 Login to %s
@@ -596,7 +628,7 @@ Logged in as %s.
 
 Logout of %s
 
-Logout of %s?
+<p>Logout of %s?</p>
 
 Logged out of %s
 
@@ -608,6 +640,60 @@ Login
 
 Logout
 
+Who am I?
+
+Forgot your password?
+
+Change your password
+
+Approve pending registrations
+
+Confirm Registration for %s
+
+%s, your registration has been approved. You can now use your password to login and edit this wiki.
+
+Confirmation failed.  Please email %s for help.
+
+Who Am I?
+
+You are logged in as %s.
+
+You are not logged in.
+
+Reset Password
+
+The password for %s was reset.  It has been emailed to the address on file.
+
+There was an error resetting the password for %s
+
+The username "%s" does not exist.
+
+Reset Password for %s
+
+<p>Reset Password?</p>
+
+Change Password for %s
+
+<p>Change Password?</p>
+
+Your current password is incorrect.
+
+Your password has been changed.
+
+Approve Pending Registrations for %s
+
+%s has been approved.
+
+There was an error approving %s.
+
+<ul>
+
+<li>%1 - %2</li>
+
+</ul>
+
+There are no pending registrations.
+
 Clearing Cache
 Bezig met leegmaken van de cache
 Done.
@@ -626,6 +712,10 @@ Local Map for %s
 
 view
 
+Self-ban by %s
+
+You have banned your own IP.
+
 Orphan List
 Lijst met Wezen
 Trail: 
@@ -666,6 +756,10 @@ Static Copy
 
 Back to %s
 Terug naar %s
+Copy to %1 succeeded: %2.
+
+Copy to %1 failed: %2.
+
 Tag
 
 Alternatively, use one of the following templates:
@@ -702,8 +796,8 @@ The translation is outdated.
 
 The page does not exist.
 
-http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
-http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
+http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s
+
 http://www.amazon.com/exec/obidos/ISBN=%s
 http://www.amazon.com/exec/obidos/ISBN=%s
 alternate
@@ -712,6 +806,14 @@ http://www.pricescan.com/books/BookDetail.asp?isbn=%s
 http://www.pricescan.com/books/BookDetail.asp?isbn=%s
 search
 zoeken
+Upload of %s file
+
 Blog
 Blog
+Matching pages:
+
+New
+
+Edit %s.
+
 END_OF_TRANSLATION
